summaryrefslogtreecommitdiffstats
path: root/kdirstat/ktreemaptile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdirstat/ktreemaptile.cpp')
-rw-r--r--kdirstat/ktreemaptile.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdirstat/ktreemaptile.cpp b/kdirstat/ktreemaptile.cpp
index 5826eb0..6efed77 100644
--- a/kdirstat/ktreemaptile.cpp
+++ b/kdirstat/ktreemaptile.cpp
@@ -79,7 +79,7 @@ KTreemapTile::init()
// Set up height (z coordinate) - one level higher than the parent so this
// will be closer to the foreground.
//
// Note that this must happen before any tqchildren are created.
// I found that out the hard way. ;-)
setZ( _parentTile ? ( _parentTile->z() + 1.0 ) : 0.0 );
@@ -184,12 +184,12 @@ KTreemapTile::createSquarifiedChildren( const TQRect & rect )
#endif
KFileInfoSortedBySizeIterator it( _orig, minSize, KDotEntryAsSubDir );
- TQRect tqchildrenRect = rect;
+ TQRect childrenRect = rect;
while ( *it )
{
- KFileInfoList row = squarify( tqchildrenRect, scale, it );
- tqchildrenRect = layoutRow( tqchildrenRect, scale, row );
+ KFileInfoList row = squarify( childrenRect, scale, it );
+ childrenRect = layoutRow( childrenRect, scale, row );
}
}
@@ -287,7 +287,7 @@ KTreemapTile::layoutRow( const TQRect & rect,
return rect;
- // Set up a cushion surface for this tqlayout row:
+ // Set up a cushion surface for this layout row:
// Add another ridge perpendicular to the row's direction
// that optically groups this row's tiles together.
@@ -79,7 +79,7 @@ KTreemapTile::init()
// will be closer to the foreground.
//
- // Note that this must happen before any tqchildren are created.
+ // Note that this must happen before any children are created.
// I found that out the hard way. ;-)
setZ( _parentTile ? ( _parentTile->z() + 1.0 ) : 0.0 );